# API Reference

::: contextguard.core.specs
::: contextguard.retrieve.protocols
::: contextguard.retrieve.planner
::: contextguard.retrieve.gating
::: contextguard.verify.claim_splitter
::: contextguard.verify.judges
::: contextguard.verify.aggregate
::: contextguard.verify.report
::: contextguard.adapters.langchain
::: contextguard.adapters.llamaindex
::: contextguard.adapters.chroma
::: contextguard.adapters.qdrant
::: contextguard.adapters.openai_provider
::: contextguard.adapters.budgeted_provider
::: contextguard.adapters.retrying_provider
::: contextguard.stores.sqlite
::: contextguard.stores.cloud
::: contextguard.pipeline.async_runner
::: contextguard.generate.generator

